@@ -23,6 +23,7 @@
 #include <akonadi/agentbase.h>
 #include <akonadi/collection.h>
 #include <akonadi/item.h>
+#include <akonadi/resourcebase.h>
 
 #include <QtCore/QObject>
 #include <QtCore/QStringList>
@@ -52,27 +53,34 @@ class ResourceScheduler : public QObject
       FetchItem,
       ChangeReplay,
       DeleteResourceCollection,
-      SyncAllDone
+      SyncAllDone,
+      Custom
     };
 
     class Task {
       static qint64 latestSerial;
 
       public:
-        Task() : serial( ++latestSerial ), type( Invalid ) {}
+        Task() : serial( ++latestSerial ), type( Invalid ), receiver( 0 ) {}
         qint64 serial;
         TaskType type;
         Collection collection;
         Item item;
         QSet<QByteArray> itemParts;
         QDBusMessage dbusMsg;
+        QObject *receiver;
+        QByteArray methodName;
+        QVariant argument;
 
         bool operator==( const Task &other ) const
         {
           return type == other.type
               && (collection == other.collection || (!collection.isValid() && !other.collection.isValid()))
               && (item == other.item || (!item.isValid() && !other.item.isValid()))
-              && itemParts == other.itemParts;
+              && itemParts == other.itemParts
+              && receiver == other.receiver
+              && methodName == other.methodName
+              && argument == other.argument;
         }
     };
 
@@ -113,6 +121,12 @@ class ResourceScheduler : public QObject
     */
     void scheduleFullSyncCompletion();
 
+    /**
+      Insert a custom taks.
+      @param methodName The method name, without signature, do not use the SLOT() macro
+    */
+    void scheduleCustomTask( QObject *receiver, const char *methodName, const QVariant &argument, ResourceBase::SchedulePriority priority = ResourceBase::Append );
+
     /**
       Returns true if no tasks are running or in the queue.
     */
@@ -144,6 +158,11 @@ class ResourceScheduler : public QObject
     */
     void deferTask();
 
+    /**
+      Remove tasks that affect @p collection.
+    */
+    void collectionRemoved( const Akonadi::Collection &collection );
+
   Q_SIGNALS:
     void executeFullSync();
     void executeCollectionSync( const Akonadi::Collection &col );
