@@ -22,6 +22,8 @@
 #include "testattribute.h"
 #include "test_utils.h"
 
+#include <akonadi/agentinstance.h>
+#include <akonadi/agentmanager.h>
 #include <akonadi/attributefactory.h>
 #include <akonadi/collectionfetchjob.h>
 #include <akonadi/itemcreatejob.h>
@@ -38,6 +40,12 @@ QTEST_AKONADIMAIN( ItemAppendTest, NoGUI )
 void ItemAppendTest::initTestCase()
 {
   Control::start();
+
+  // switch all resources offline to reduce interference from them
+  foreach ( Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances() )
+    agent.setIsOnline( false );
+
+  AttributeFactory::registerAttribute<TestAttribute>();
 }
 
 void ItemAppendTest::testItemAppend_data()
@@ -48,6 +56,7 @@ void ItemAppendTest::testItemAppend_data()
   QTest::newRow( "non empty" ) << QString( "remote-id" );
   QTest::newRow( "whitespace" ) << QString( "remote id" );
   QTest::newRow( "quotes" ) << QString ( "\"remote\" id" );
+  QTest::newRow( "brackets" ) << QString( "[remote id]" );
 }
 
 void ItemAppendTest::testItemAppend()
@@ -63,16 +72,19 @@ void ItemAppendTest::testItemAppend()
   item.setMimeType( "application/octet-stream" );
   item.setFlag( "TestFlag" );
   item.setSize( 3456 );
-  ItemCreateJob *job = new ItemCreateJob( item, Collection( testFolder1 ), this );
+  ItemCreateJob *job = new ItemCreateJob( item, testFolder1, this );
   AKVERIFYEXEC( job );
   ref = job->item();
+  QCOMPARE( ref.parentCollection(), testFolder1 );
 
   ItemFetchJob *fjob = new ItemFetchJob( testFolder1, this );
+  fjob->fetchScope().setAncestorRetrieval( ItemFetchScope::Parent );
   AKVERIFYEXEC( fjob );
   QCOMPARE( fjob->items().count(), 1 );
   QCOMPARE( fjob->items()[0], ref );
   QCOMPARE( fjob->items()[0].remoteId(), remoteId );
   QVERIFY( fjob->items()[0].flags().contains( "TestFlag" ) );
+  QCOMPARE( fjob->items()[0].parentCollection(), ref.parentCollection() );
 
   qint64 size = 3456;
   QCOMPARE( fjob->items()[0].size(), size );
@@ -172,8 +184,6 @@ void ItemAppendTest::testIllegalAppend()
 
 void ItemAppendTest::testMultipartAppend()
 {
-  AttributeFactory::registerAttribute<TestAttribute>();
-
   const Collection testFolder1( collectionIdFromPath( "res2/space folder" ) );
   QVERIFY( testFolder1.isValid() );
 
@@ -201,6 +211,25 @@ void ItemAppendTest::testMultipartAppend()
   AKVERIFYEXEC( djob );
 }
 
+void ItemAppendTest::testInvalidMultipartAppend()
+{
+  Item item;
+  item.setMimeType( "application/octet-stream" );
+  item.setPayload<QByteArray>( "body data" );
+  item.attribute<TestAttribute>( Item::AddIfMissing )->data = "extra data";
+  item.setFlag( "TestFlag" );
+  ItemCreateJob *job = new ItemCreateJob( item, Collection( -1 ), this );
+  QVERIFY( !job->exec() );
+
+  Item item2;
+  item2.setMimeType( "application/octet-stream" );
+  item2.setPayload<QByteArray>( "more body data" );
+  item2.attribute<TestAttribute>( Item::AddIfMissing )->data = "even more extra data";
+  item2.setFlag( "TestFlag" );
+  ItemCreateJob *job2 = new ItemCreateJob( item2, Collection( -1 ), this );
+  QVERIFY( !job2->exec() );
+}
+
 void ItemAppendTest::testItemSize_data()
 {
   QTest::addColumn<Akonadi::Item>( "item" );
