@@ -98,25 +98,25 @@ bool HtmlExport::save( QTextStream *ts )
   ts->setCodec( "UTF-8" );
   // Write HTML header
   *ts << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" ";
-  *ts << "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">"<<endl;
+  *ts << "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">" << endl;
 
   *ts << "<html><head>" << endl;
   *ts << "  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=";
-  *ts << "UTF-8\" />"<<endl;
+  *ts << "UTF-8\" />" << endl;
   if ( !d->mSettings->pageTitle().isEmpty() ) {
-    *ts << "  <title>" << d->mSettings->pageTitle() << "</title>"<<endl;
+    *ts << "  <title>" << d->mSettings->pageTitle() << "</title>" << endl;
   }
-  *ts << "  <style type=\"text/css\">"<<endl;
+  *ts << "  <style type=\"text/css\">" << endl;
   *ts << styleSheet();
-  *ts << "  </style>"<<endl;
-  *ts << "</head><body>"<<endl;
+  *ts << "  </style>" << endl;
+  *ts << "</head><body>" << endl;
 
   // FIXME: Write header
   // (Heading, Calendar-Owner, Calendar-Date, ...)
 
   if ( d->mSettings->eventView() || d->mSettings->monthView() || d->mSettings->weekView() ) {
     if ( !d->mSettings->eventTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->eventTitle() << "</h1>"<<endl;
+      *ts << "<h1>" << d->mSettings->eventTitle() << "</h1>" << endl;
     }
 
     // Write Week View
@@ -136,7 +136,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Todo List
   if ( d->mSettings->todoView() ) {
     if ( !d->mSettings->todoListTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->todoListTitle() << "</h1>"<<endl;
+      *ts << "<h1>" << d->mSettings->todoListTitle() << "</h1>" << endl;
     }
     createTodoList( ts );
   }
@@ -144,7 +144,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Journals
   if ( d->mSettings->journalView() ) {
     if ( !d->mSettings->journalTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->journalTitle() << "</h1>"<<endl;
+      *ts << "<h1>" << d->mSettings->journalTitle() << "</h1>" << endl;
     }
     createJournalView( ts );
   }
@@ -152,7 +152,7 @@ bool HtmlExport::save( QTextStream *ts )
   // Write Free/Busy
   if ( d->mSettings->freeBusyView() ) {
     if ( !d->mSettings->freeBusyTitle().isEmpty() ) {
-      *ts << "<h1>" << d->mSettings->freeBusyTitle() << "</h1>"<<endl;
+      *ts << "<h1>" << d->mSettings->freeBusyTitle() << "</h1>" << endl;
     }
     createFreeBusyView( ts );
   }
@@ -160,7 +160,7 @@ bool HtmlExport::save( QTextStream *ts )
   createFooter( ts );
 
   // Write HTML trailer
-  *ts << "</body></html>"<<endl;
+  *ts << "</body></html>" << endl;
 
   return true;
 }
@@ -182,7 +182,7 @@ void HtmlExport::createMonthView( QTextStream *ts )
     QString hYear = hDate.toString( "yyyy" );
     *ts << "<h2>"
         << i18nc( "@title month and year", "%1 %2", hMon, hYear )
-        << "</h2>"<<endl;
+        << "</h2>" << endl;
     if ( KGlobal::locale()->weekStartDay() == 1 ) {
       start = start.addDays( 1 - start.dayOfWeek() );
     } else {
@@ -190,18 +190,18 @@ void HtmlExport::createMonthView( QTextStream *ts )
         start = start.addDays( -start.dayOfWeek() );
       }
     }
-    *ts << "<table border=\"1\">"<<endl;
+    *ts << "<table border=\"1\">" << endl;
 
     // Write table header
     *ts << "  <tr>";
     for ( int i=0; i < 7; ++i ) {
       *ts << "<th>" << KGlobal::locale()->calendar()->weekDayName( start.addDays(i) ) << "</th>";
     }
-    *ts << "</tr>"<<endl;
+    *ts << "</tr>" << endl;
 
     // Write days
     while ( start <= end ) {
-      *ts << "  <tr>"<<endl;
+      *ts << "  <tr>" << endl;
       for ( int i=0; i < 7; ++i ) {
         *ts << "    <td valign=\"top\"><table border=\"0\">";
 
@@ -238,12 +238,12 @@ void HtmlExport::createMonthView( QTextStream *ts )
           }
         }
 
-        *ts << "</td></tr></table></td>"<<endl;
+        *ts << "</td></tr></table></td>" << endl;
         start = start.addDays( 1 );
       }
-      *ts << "  </tr>"<<endl;
+      *ts << "  </tr>" << endl;
     }
-    *ts << "</table>"<<endl;
+    *ts << "</table>" << endl;
     startmonth += 1;
     if ( startmonth > 12 ) {
       startyear += 1;
@@ -257,31 +257,31 @@ void HtmlExport::createMonthView( QTextStream *ts )
 void HtmlExport::createEventList( QTextStream *ts )
 {
   int columns = 3;
-  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">"<<endl;
-  *ts << "  <tr>"<<endl;
+  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">" << endl;
+  *ts << "  <tr>" << endl;
   *ts << "    <th class=\"sum\">" << i18nc( "@title:column event start time",
-                                            "Start Time" ) << "</th>"<<endl;
+                                            "Start Time" ) << "</th>" << endl;
   *ts << "    <th>" << i18nc( "@title:column event end time",
-                              "End Time" ) << "</th>"<<endl;
+                              "End Time" ) << "</th>" << endl;
   *ts << "    <th>" << i18nc( "@title:column event description",
-                              "Event" ) << "</th>"<<endl;
+                              "Event" ) << "</th>" << endl;
   if ( d->mSettings->eventLocation() ) {
     *ts << "    <th>" << i18nc( "@title:column event locatin",
-                                "Location" ) << "</th>"<<endl;
+                                "Location" ) << "</th>" << endl;
     ++columns;
   }
   if ( d->mSettings->eventCategories() ) {
     *ts << "    <th>" << i18nc( "@title:column event categories",
-                                "Categories" ) << "</th>"<<endl;
+                                "Categories" ) << "</th>" << endl;
     ++columns;
   }
   if ( d->mSettings->eventAttendees() ) {
     *ts << "    <th>" << i18nc( "@title:column event attendees",
-                                "Attendees" ) << "</th>"<<endl;
+                                "Attendees" ) << "</th>" << endl;
     ++columns;
   }
 
-  *ts << "  </tr>"<<endl;
+  *ts << "  </tr>" << endl;
 
   for ( QDate dt = fromDate(); dt <= toDate(); dt = dt.addDays(1) ) {
     kDebug() << "Getting events for" << dt.toString();
@@ -292,7 +292,7 @@ void HtmlExport::createEventList( QTextStream *ts )
       *ts << "  <tr><td colspan=\"" << QString::number( columns )
           << "\" class=\"datehead\"><i>"
           << KGlobal::locale()->formatDate( dt )
-          << "</i></td></tr>"<<endl;
+          << "</i></td></tr>" << endl;
 
       Event::List::ConstIterator it;
       for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
@@ -303,60 +303,60 @@ void HtmlExport::createEventList( QTextStream *ts )
     }
   }
 
-  *ts << "</table>"<<endl;
+  *ts << "</table>" << endl;
 }
 
 void HtmlExport::createEvent ( QTextStream *ts, Event *event,
                                QDate date, bool withDescription )
 {
   kDebug() << event->summary();
-  *ts << "  <tr>"<<endl;
+  *ts << "  <tr>" << endl;
 
   if ( !event->allDay() ) {
     if ( event->isMultiDay( d->mCalendar->timeSpec() ) && ( event->dtStart().date() != date ) ) {
-      *ts << "    <td>&nbsp;</td>"<<endl;
+      *ts << "    <td>&nbsp;</td>" << endl;
     } else {
       *ts << "    <td valign=\"top\">"
           << IncidenceFormatter::timeToString( event->dtStart(), true, d->mCalendar->timeSpec() )
-          << "</td>"<<endl;
+          << "</td>" << endl;
     }
     if ( event->isMultiDay( d->mCalendar->timeSpec() ) && ( event->dtEnd().date() != date ) ) {
-      *ts << "    <td>&nbsp;</td>"<<endl;
+      *ts << "    <td>&nbsp;</td>" << endl;
     } else {
       *ts << "    <td valign=\"top\">"
           << IncidenceFormatter::timeToString( event->dtEnd(), true, d->mCalendar->timeSpec() )
-          << "</td>"<<endl;
+          << "</td>" << endl;
     }
   } else {
-    *ts << "    <td>&nbsp;</td><td>&nbsp;</td>"<<endl;
+    *ts << "    <td>&nbsp;</td><td>&nbsp;</td>" << endl;
   }
 
-  *ts << "    <td class=\"sum\">"<<endl;
-  *ts << "      <b>" << cleanChars( event->summary() ) << "</b>"<<endl;
+  *ts << "    <td class=\"sum\">" << endl;
+  *ts << "      <b>" << cleanChars( event->summary() ) << "</b>" << endl;
   if ( withDescription && !event->description().isEmpty() ) {
-    *ts << "      <p>" << breakString( cleanChars( event->description() ) ) << "</p>"<<endl;
+    *ts << "      <p>" << breakString( cleanChars( event->description() ) ) << "</p>" << endl;
   }
-  *ts << "    </td>"<<endl;
+  *ts << "    </td>" << endl;
 
   if ( d->mSettings->eventLocation() ) {
-    *ts << "  <td>"<<endl;
+    *ts << "  <td>" << endl;
     formatLocation( ts, event );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
   if ( d->mSettings->eventCategories() ) {
-    *ts << "  <td>"<<endl;
+    *ts << "  <td>" << endl;
     formatCategories( ts, event );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
   if ( d->mSettings->eventAttendees() ) {
-    *ts << "  <td>"<<endl;
+    *ts << "  <td>" << endl;
     formatAttendees( ts, event );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
-  *ts << "  </tr>"<<endl;
+  *ts << "  </tr>" << endl;
 }
 
 void HtmlExport::createTodoList ( QTextStream *ts )
@@ -396,28 +396,29 @@ void HtmlExport::createTodoList ( QTextStream *ts )
   }
 
   int columns = 3;
-  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">"<<endl;
-  *ts << "  <tr>"<<endl;
-  *ts << "    <th class=\"sum\">" << i18nc( "@title:column", "To-do" ) << "</th>"<<endl;
-  *ts << "    <th>" << i18nc( "@title:column to-do priority", "Priority" ) << "</th>"<<endl;
-  *ts << "    <th>" << i18nc( "@title:column to-do percent completed", "Completed" ) << "</th>"<<endl;
+  *ts << "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\">" << endl;
+  *ts << "  <tr>" << endl;
+  *ts << "    <th class=\"sum\">" << i18nc( "@title:column", "To-do" ) << "</th>" << endl;
+  *ts << "    <th>" << i18nc( "@title:column to-do priority", "Priority" ) << "</th>" << endl;
+  *ts << "    <th>" << i18nc( "@title:column to-do percent completed",
+                              "Completed" ) << "</th>" << endl;
   if ( d->mSettings->taskDueDate() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do due date", "Due Date" ) << "</th>"<<endl;
+    *ts << "    <th>" << i18nc( "@title:column to-do due date", "Due Date" ) << "</th>" << endl;
     ++columns;
   }
   if ( d->mSettings->taskLocation() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do location", "Location" ) << "</th>"<<endl;
+    *ts << "    <th>" << i18nc( "@title:column to-do location", "Location" ) << "</th>" << endl;
     ++columns;
   }
   if ( d->mSettings->taskCategories() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do categories", "Categories" ) << "</th>"<<endl;
+    *ts << "    <th>" << i18nc( "@title:column to-do categories", "Categories" ) << "</th>" << endl;
     ++columns;
   }
   if ( d->mSettings->taskAttendees() ) {
-    *ts << "    <th>" << i18nc( "@title:column to-do attendees", "Attendees" ) << "</th>"<<endl;
+    *ts << "    <th>" << i18nc( "@title:column to-do attendees", "Attendees" ) << "</th>" << endl;
     ++columns;
   }
-  *ts << "  </tr>"<<endl;
+  *ts << "  </tr>" << endl;
 
   // Create top-level list.
   for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
@@ -431,15 +432,15 @@ void HtmlExport::createTodoList ( QTextStream *ts )
     Incidence::List relations = (*it)->relations();
     if ( relations.count() ) {
       // Generate sub-to-do list
-      *ts << "  <tr>"<<endl;
+      *ts << "  <tr>" << endl;
       *ts << "    <td class=\"subhead\" colspan=";
       *ts << "\"" << QString::number(columns) << "\"";
       *ts << "><a name=\"sub" << (*it)->uid() << "\"></a>"
           << i18nc( "@title:column sub-to-dos of the parent to-do",
                     "Sub-To-dos of: " ) << "<a href=\"#"
           << (*it)->uid() << "\"><b>" << cleanChars( (*it)->summary() )
-          << "</b></a></td>"<<endl;
-      *ts << "  </tr>"<<endl;
+          << "</b></a></td>" << endl;
+      *ts << "  </tr>" << endl;
 
       Todo::List sortedList;
       // FIXME: Sort list by priorities. This is brute force and should be
@@ -468,7 +469,7 @@ void HtmlExport::createTodoList ( QTextStream *ts )
     }
   }
 
-  *ts << "</table>"<<endl;
+  *ts << "</table>" << endl;
 }
 
 void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
@@ -478,52 +479,52 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
   bool completed = todo->isCompleted();
   Incidence::List relations = todo->relations();
 
-  *ts << "<tr>"<<endl;
+  *ts << "<tr>" << endl;
 
   *ts << "  <td class=\"sum";
   if (completed) *ts << "done";
-  *ts << "\">"<<endl;
-  *ts << "    <a name=\"" << todo->uid() << "\"></a>"<<endl;
-  *ts << "    <b>" << cleanChars( todo->summary() ) << "</b>"<<endl;
+  *ts << "\">" << endl;
+  *ts << "    <a name=\"" << todo->uid() << "\"></a>" << endl;
+  *ts << "    <b>" << cleanChars( todo->summary() ) << "</b>" << endl;
   if ( !todo->description().isEmpty() ) {
-    *ts << "    <p>" << breakString( cleanChars( todo->description() ) ) << "</p>"<<endl;
+    *ts << "    <p>" << breakString( cleanChars( todo->description() ) ) << "</p>" << endl;
   }
   if ( relations.count() ) {
     *ts << "    <div align=\"right\"><a href=\"#sub" << todo->uid()
         << "\">" << i18nc( "@title:column sub-to-dos of the parent to-do",
-                           "Sub-To-dos" ) << "</a></div>"<<endl;
+                           "Sub-To-dos" ) << "</a></div>" << endl;
   }
-  *ts << "  </td>"<<endl;
+  *ts << "  </td>" << endl;
 
   *ts << "  <td";
   if ( completed ) {
     *ts << " class=\"done\"";
   }
-  *ts << ">"<<endl;
-  *ts << "    " << todo->priority() <<endl;
-  *ts << "  </td>"<<endl;
+  *ts << ">" << endl;
+  *ts << "    " << todo->priority() << endl;
+  *ts << "  </td>" << endl;
 
   *ts << "  <td";
   if ( completed ) {
     *ts << " class=\"done\"";
   }
-  *ts << ">"<<endl;
+  *ts << ">" << endl;
   *ts << "    " << i18nc( "@info/plain to-do percent complete",
-                          "%1 %", todo->percentComplete() ) <<endl;
-  *ts << "  </td>"<<endl;
+                          "%1 %", todo->percentComplete() ) << endl;
+  *ts << "  </td>" << endl;
 
   if ( d->mSettings->taskDueDate() ) {
     *ts << "  <td";
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">"<<endl;
+    *ts << ">" << endl;
     if ( todo->hasDueDate() ) {
-      *ts << "    " << IncidenceFormatter::dateToString(todo->dtDue(true)) <<endl;
+      *ts << "    " << IncidenceFormatter::dateToString( todo->dtDue( true ) ) << endl;
     } else {
-      *ts << "    &nbsp;"<<endl;
+      *ts << "    &nbsp;" << endl;
     }
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
   if ( d->mSettings->taskLocation() ) {
@@ -531,9 +532,9 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">"<<endl;
+    *ts << ">" << endl;
     formatLocation( ts, todo );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
   if ( d->mSettings->taskCategories() ) {
@@ -541,9 +542,9 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">"<<endl;
+    *ts << ">" << endl;
     formatCategories( ts, todo );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
   if ( d->mSettings->taskAttendees() ) {
@@ -551,12 +552,12 @@ void HtmlExport::createTodo( QTextStream *ts, Todo *todo )
     if ( completed ) {
       *ts << " class=\"done\"";
     }
-    *ts << ">"<<endl;
+    *ts << ">" << endl;
     formatAttendees( ts, todo );
-    *ts << "  </td>"<<endl;
+    *ts << "  </td>" << endl;
   }
 
-  *ts << "</tr>"<<endl;
+  *ts << "</tr>" << endl;
 }
 
 void HtmlExport::createWeekView( QTextStream *ts )
@@ -597,18 +598,18 @@ bool HtmlExport::checkSecrecy( Incidence *incidence )
 void HtmlExport::formatLocation( QTextStream *ts, Incidence *incidence )
 {
   if ( !incidence->location().isEmpty() ) {
-    *ts << "    " << cleanChars( incidence->location() ) <<endl;
+    *ts << "    " << cleanChars( incidence->location() ) << endl;
   } else {
-    *ts << "    &nbsp;"<<endl;
+    *ts << "    &nbsp;" << endl;
   }
 }
 
 void HtmlExport::formatCategories( QTextStream *ts, Incidence *incidence )
 {
   if ( !incidence->categoriesStr().isEmpty() ) {
-    *ts << "    " << cleanChars( incidence->categoriesStr() ) <<endl;
+    *ts << "    " << cleanChars( incidence->categoriesStr() ) << endl;
   } else {
-    *ts << "    &nbsp;"<<endl;
+    *ts << "    &nbsp;" << endl;
   }
 }
 
@@ -625,7 +626,7 @@ void HtmlExport::formatAttendees( QTextStream *ts, Incidence *incidence )
       KABC::Addressee o = addressList.first();
       if ( !o.isEmpty() && addressList.size() < 2 ) {
         *ts << "<a href=\"mailto:" << incidence->organizer().email() << "\">";
-        *ts << cleanChars( o.formattedName() ) << "</a>"<<endl;
+        *ts << cleanChars( o.formattedName() ) << "</a>" << endl;
       } else {
         *ts << incidence->organizer().fullName();
       }
@@ -643,10 +644,10 @@ void HtmlExport::formatAttendees( QTextStream *ts, Incidence *incidence )
       } else {
         *ts << "    " << cleanChars( a->name() );
       }
-      *ts << "<br />" <<endl;
+      *ts << "<br />" << endl;
     }
   } else {
-    *ts << "    &nbsp;"<<endl;
+    *ts << "    &nbsp;" << endl;
   }
 }
 
@@ -705,7 +706,7 @@ void HtmlExport::createFooter( QTextStream *ts )
                         "with %1", d->mSettings->creditName() );
     }
   }
-  *ts << "<p>" << trailer << "</p>"<<endl;
+  *ts << "<p>" << trailer << "</p>" << endl;
 }
 
 QString cleanChars( const QString &text )
