@@ -227,7 +227,7 @@ QString Query::Private::marshal( const QVariant &arg ) const
         QString markup;
         markup += "<value><array><data>";
         while ( dataIterator.hasNext() ) {
-          markup += "<string><![CDATA[" + dataIterator.next() + "]]></string>\r\n";
+          markup += "<value><string><![CDATA[" + dataIterator.next() + "]]></string></value>\r\n";
         }
         markup += "</data></array></value>";
         return markup;
