@@ -18,45 +18,64 @@
 */
 
 #include "transportmanager.h"
+#include "addtransportdialog.h"
+#include "resourcesendjob_p.h"
 #include "mailtransport_defs.h"
-#include "transport.h"
-#include "smtpjob.h"
+#include "sendmailconfigwidget.h"
 #include "sendmailjob.h"
-
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kemailsettings.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <krandom.h>
-#include <kurl.h>
-#include <kwallet.h>
-#include <kconfiggroup.h>
+#include "smtpconfigwidget.h"
+#include "smtpjob.h"
+#include "transport.h"
+#include "transportconfigwidget.h"
+#include "transportjob.h"
+#include "transporttype.h"
+#include "transporttype_p.h"
+#include "transportconfigdialog.h"
 
 #include <QApplication>
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusConnectionInterface>
+#include <QPointer>
 #include <QRegExp>
 #include <QStringList>
 
+#include <KConfig>
+#include <KConfigGroup>
+#include <KDebug>
+#include <kemailsettings.h>
+#include <KLocale>
+#include <KMessageBox>
+#include <KRandom>
+#include <KUrl>
+#include <KWallet/Wallet>
+
+#include <akonadi/agentinstance.h>
+#include <akonadi/agentmanager.h>
+
 using namespace MailTransport;
 using namespace KWallet;
 
+namespace MailTransport {
 /**
  * Private class that helps to provide binary compatibility between releases.
  * @internal
  */
-class TransportManager::Private
+class TransportManagerPrivate
 {
   public:
-    Private() {}
-    ~Private() {
+    TransportManagerPrivate( TransportManager *parent )
+      : q( parent )
+    {
+    }
+
+    ~TransportManagerPrivate() {
       delete config;
       qDeleteAll( transports );
     }
 
     KConfig *config;
     QList<Transport *> transports;
+    TransportType::List types;
     bool myOwnChange;
     bool appliedChange;
     KWallet::Wallet *wallet;
@@ -65,8 +84,29 @@ class TransportManager::Private
     int defaultTransportId;
     bool isMainInstance;
     QList<TransportJob *> walletQueue;
+    TransportManager *q;
+
+    void readConfig();
+    void writeConfig();
+    void fillTypes();
+    int createId() const;
+    void prepareWallet();
+    void validateDefault();
+    void migrateToWallet();
+
+    // Slots
+    void slotTransportsChanged();
+    void slotWalletOpened( bool success );
+    void dbusServiceOwnerChanged( const QString &service,
+                                  const QString &oldOwner,
+                                  const QString &newOwner );
+    void agentTypeAdded( const Akonadi::AgentType &atype );
+    void agentTypeRemoved( const Akonadi::AgentType &atype );
+    void jobResult( KJob *job );
 };
 
+}
+
 class StaticTransportManager : public TransportManager
 {
   public:
@@ -80,7 +120,7 @@ static void destroyStaticTransportManager() {
 }
 
 TransportManager::TransportManager()
-  : QObject(), d( new Private )
+  : QObject(), d( new TransportManagerPrivate( this ) )
 {
   KGlobal::locale()->insertCatalog( QLatin1String( "libmailtransport" ) );
   qAddPostRoutine( destroyStaticTransportManager );
@@ -105,6 +145,8 @@ TransportManager::TransportManager()
   connect( QDBusConnection::sessionBus().interface(),
            SIGNAL(serviceOwnerChanged(QString,QString,QString)),
            SLOT(dbusServiceOwnerChanged(QString,QString,QString)) );
+
+  d->fillTypes();
 }
 
 TransportManager::~TransportManager()
@@ -117,7 +159,7 @@ TransportManager *TransportManager::self()
 {
   if ( !sSelf ) {
     sSelf = new StaticTransportManager;
-    sSelf->readConfig();
+    sSelf->d->readConfig();
   }
   return sSelf;
 }
@@ -154,9 +196,14 @@ QList< Transport * > TransportManager::transports() const
   return d->transports;
 }
 
+TransportType::List TransportManager::types() const
+{
+  return d->types;
+}
+
 Transport *TransportManager::createTransport() const
 {
-  int id = createId();
+  int id = d->createId();
   Transport *t = new Transport( QString::number( id ) );
   t->setId( id );
   return t;
@@ -165,11 +212,13 @@ Transport *TransportManager::createTransport() const
 void TransportManager::addTransport( Transport *transport )
 {
   if ( d->transports.contains( transport ) ) {
+    kDebug() << "Already have this transport.";
     return;
   }
 
+  kDebug() << "Added transport" << transport;
   d->transports.append( transport );
-  validateDefault();
+  d->validateDefault();
   emitChangesCommitted();
 }
 
@@ -202,17 +251,89 @@ void TransportManager::createDefaultTransport()
   }
 }
 
+bool TransportManager::showTransportCreationDialog( QWidget *parent,
+                                                    ShowCondition showCondition )
+{
+  if ( showCondition == IfNoTransportExists ) {
+    if ( !isEmpty() ) {
+      return true;
+    }
+
+    const int response = KMessageBox::messageBox( parent,
+                   KMessageBox::WarningContinueCancel,
+                   i18n( "You must create an outgoing account before sending." ),
+                   i18n( "Create Account Now?" ),
+                   KGuiItem( i18n( "Create Account Now" ) ) );
+    if ( response != KMessageBox::Continue ) {
+      return false;
+    }
+  }
+
+  QPointer<AddTransportDialog> dialog = new AddTransportDialog( parent );
+  const bool accepted = ( dialog->exec() == QDialog::Accepted );
+  delete dialog;
+  return accepted;
+}
+
+bool TransportManager::configureTransport( Transport *transport, QWidget *parent )
+{
+  if( transport->type() == Transport::EnumType::Akonadi ) {
+    using namespace Akonadi;
+    AgentInstance instance = AgentManager::self()->instance( transport->host() );
+    if( !instance.isValid() ) {
+      kWarning() << "Invalid resource instance" << transport->host();
+    }
+    instance.configure( parent ); // Async...
+    transport->writeConfig();
+    return true; // No way to know here if the user cancelled or not.
+  }
+
+  QPointer<KDialog> dialog = new KDialog( parent );
+  TransportConfigWidget *configWidget = 0;
+  switch( transport->type() ) {
+    case Transport::EnumType::SMTP:
+      {
+        configWidget = new SMTPConfigWidget( transport, dialog );
+        break;
+      }
+    case Transport::EnumType::Sendmail:
+      {
+        configWidget =  new SendmailConfigWidget( transport, dialog );
+        break;
+      }
+    default:
+      {
+        Q_ASSERT( false );
+        delete dialog;
+        return false;
+      }
+  }
+  dialog->setMainWidget( configWidget );
+  dialog->setCaption( i18n( "Configure account" ) );
+  dialog->setButtons( KDialog::Ok | KDialog::Cancel );
+  bool okClicked = ( dialog->exec() == QDialog::Accepted );
+  if( okClicked ) {
+    configWidget->apply(); // calls transport->writeConfig()
+  }
+  delete dialog;
+  return okClicked;
+}
+
 TransportJob *TransportManager::createTransportJob( int transportId )
 {
   Transport *t = transportById( transportId, false );
   if ( !t ) {
     return 0;
   }
+  t = t->clone(); // Jobs delete their transports.
+  t->updatePasswordState();
   switch ( t->type() ) {
-  case Transport::EnumType::SMTP:
-    return new SmtpJob( t->clone(), this );
-  case Transport::EnumType::Sendmail:
-    return new SendmailJob( t->clone(), this );
+    case Transport::EnumType::SMTP:
+      return new SmtpJob( t, this );
+    case Transport::EnumType::Sendmail:
+      return new SendmailJob( t, this );
+    case Transport::EnumType::Akonadi:
+      return new ResourceSendJob( t, this );
   }
   Q_ASSERT( false );
   return 0;
@@ -282,7 +403,7 @@ void TransportManager::setDefaultTransport( int id )
     return;
   }
   d->defaultTransportId = id;
-  writeConfig();
+  d->writeConfig();
 }
 
 void TransportManager::removeTransport( int id )
@@ -292,21 +413,33 @@ void TransportManager::removeTransport( int id )
     return;
   }
   emit transportRemoved( t->id(), t->name() );
+
+  // Kill the resource, if Akonadi-type transport.
+  if( t->type() == Transport::EnumType::Akonadi ) {
+    using namespace Akonadi;
+    const AgentInstance instance = AgentManager::self()->instance( t->host() );
+    if( !instance.isValid() ) {
+      kWarning() << "Could not find resource instance.";
+    }
+    AgentManager::self()->removeInstance( instance );
+  }
+
   d->transports.removeAll( t );
-  validateDefault();
+  d->validateDefault();
   QString group = t->currentGroup();
   delete t;
   d->config->deleteGroup( group );
-  writeConfig();
+  d->writeConfig();
+
 }
 
-void TransportManager::readConfig()
+void TransportManagerPrivate::readConfig()
 {
-  QList<Transport *> oldTransports = d->transports;
-  d->transports.clear();
+  QList<Transport *> oldTransports = transports;
+  transports.clear();
 
   QRegExp re( QLatin1String( "^Transport (.+)$" ) );
-  QStringList groups = d->config->groupList().filter( re );
+  QStringList groups = config->groupList().filter( re );
   foreach ( const QString &s, groups ) {
     re.indexIn( s );
     Transport *t = 0;
@@ -329,22 +462,22 @@ void TransportManager::readConfig()
       t->setId( createId() );
       t->writeConfig();
     }
-    d->transports.append( t );
+    transports.append( t );
   }
 
   qDeleteAll( oldTransports );
   oldTransports.clear();
 
   // read default transport
-  KConfigGroup group( d->config, "General" );
-  d->defaultTransportId = group.readEntry( "default-transport", 0 );
-  if ( d->defaultTransportId == 0 ) {
+  KConfigGroup group( config, "General" );
+  defaultTransportId = group.readEntry( "default-transport", 0 );
+  if ( defaultTransportId == 0 ) {
     // migrated default transport contains the name instead
     QString name = group.readEntry( "default-transport", QString() );
     if ( !name.isEmpty() ) {
-      Transport *t = transportByName( name, false );
+      Transport *t = q->transportByName( name, false );
       if ( t ) {
-        d->defaultTransportId = t->id();
+        defaultTransportId = t->id();
         writeConfig();
       }
     }
@@ -353,12 +486,61 @@ void TransportManager::readConfig()
   migrateToWallet();
 }
 
-void TransportManager::writeConfig()
+void TransportManagerPrivate::writeConfig()
 {
-  KConfigGroup group( d->config, "General" );
-  group.writeEntry( "default-transport", d->defaultTransportId );
-  d->config->sync();
-  emitChangesCommitted();
+  KConfigGroup group( config, "General" );
+  group.writeEntry( "default-transport", defaultTransportId );
+  config->sync();
+  q->emitChangesCommitted();
+}
+
+void TransportManagerPrivate::fillTypes()
+{
+  Q_ASSERT( types.isEmpty() );
+
+  // SMTP.
+  {
+    TransportType type;
+    type.d->mType = Transport::EnumType::SMTP;
+    type.d->mName = i18nc( "@option SMTP transport", "SMTP" );
+    type.d->mDescription = i18n( "An SMTP server on the Internet" );
+    types << type;
+  }
+
+  // Sendmail.
+  {
+    TransportType type;
+    type.d->mType = Transport::EnumType::Sendmail;
+    type.d->mName = i18nc( "@option sendmail transport", "Sendmail" );
+    type.d->mDescription = i18n( "A local sendmail installation" );
+    types << type;
+  }
+
+  // All Akonadi resources with MailTransport capability.
+  {
+    using namespace Akonadi;
+    foreach ( const AgentType &atype, AgentManager::self()->types() ) {
+      // TODO probably the string "MailTransport" should be #defined somewhere
+      // and used like that in the resources (?)
+      if( atype.capabilities().contains( QLatin1String( "MailTransport" ) ) ) {
+        TransportType type;
+        type.d->mType = Transport::EnumType::Akonadi;
+        type.d->mAgentType = atype;
+        type.d->mName = atype.name();
+        type.d->mDescription = atype.description();
+        types << type;
+        kDebug() << "Found Akonadi type" << atype.name();
+      }
+    }
+
+    // Watch for appearing and disappearing types.
+    QObject::connect( AgentManager::self(), SIGNAL(typeAdded(Akonadi::AgentType)),
+        q, SLOT(agentTypeAdded(Akonadi::AgentType)) );
+    QObject::connect( AgentManager::self(), SIGNAL(typeRemoved(Akonadi::AgentType)),
+        q, SLOT(agentTypeRemoved(Akonadi::AgentType)) );
+  }
+
+  kDebug() << "Have SMTP, Sendmail, and" << types.count() - 2 << "Akonadi types.";
 }
 
 void TransportManager::emitChangesCommitted()
@@ -369,26 +551,26 @@ void TransportManager::emitChangesCommitted()
   emit changesCommitted();
 }
 
-void TransportManager::slotTransportsChanged()
+void TransportManagerPrivate::slotTransportsChanged()
 {
-  if ( d->myOwnChange && d->appliedChange ) {
-    d->myOwnChange = false;
-    d->appliedChange = false;
+  if ( myOwnChange && appliedChange ) {
+    myOwnChange = false;
+    appliedChange = false;
     return;
   }
 
   kDebug();
-  d->config->reparseConfiguration();
+  config->reparseConfiguration();
   // FIXME: this deletes existing transport objects!
   readConfig();
-  d->appliedChange = true; // to prevent recursion
-  emit transportsChanged();
+  appliedChange = true; // to prevent recursion
+  emit q->transportsChanged();
 }
 
-int TransportManager::createId() const
+int TransportManagerPrivate::createId() const
 {
   QList<int> usedIds;
-  foreach ( Transport *t, d->transports ) {
+  foreach ( Transport *t, transports ) {
     usedIds << t->id();
   }
   usedIds << 0; // 0 is default for unknown
@@ -424,19 +606,19 @@ KWallet::Wallet * TransportManager::wallet()
     return 0;
   }
 
-  prepareWallet();
+  d->prepareWallet();
   return d->wallet;
 }
 
-void TransportManager::prepareWallet()
+void TransportManagerPrivate::prepareWallet()
 {
-  if ( !d->wallet ) {
+  if ( !wallet ) {
     return;
   }
-  if ( !d->wallet->hasFolder( WALLET_FOLDER ) ) {
-    d->wallet->createFolder( WALLET_FOLDER );
+  if ( !wallet->hasFolder( WALLET_FOLDER ) ) {
+    wallet->createFolder( WALLET_FOLDER );
   }
-  d->wallet->setFolder( WALLET_FOLDER );
+  wallet->setFolder( WALLET_FOLDER );
 }
 
 void TransportManager::loadPasswords()
@@ -495,33 +677,33 @@ void TransportManager::loadPasswordsAsync()
   }
 }
 
-void TransportManager::slotWalletOpened( bool success )
+void TransportManagerPrivate::slotWalletOpened( bool success )
 {
   kDebug();
-  d->walletAsyncOpen = false;
+  walletAsyncOpen = false;
   if ( !success ) {
-    d->walletOpenFailed = true;
-    delete d->wallet;
-    d->wallet = 0;
+    walletOpenFailed = true;
+    delete wallet;
+    wallet = 0;
   } else {
     prepareWallet();
   }
-  loadPasswords();
+  q->loadPasswords();
 }
 
-void TransportManager::validateDefault()
+void TransportManagerPrivate::validateDefault()
 {
-  if ( !transportById( d->defaultTransportId, false ) ) {
-    if ( isEmpty() ) {
-      d->defaultTransportId = -1;
+  if ( !q->transportById( defaultTransportId, false ) ) {
+    if ( q->isEmpty() ) {
+      defaultTransportId = -1;
     } else {
-      d->defaultTransportId = d->transports.first()->id();
+      defaultTransportId = transports.first()->id();
       writeConfig();
     }
   }
 }
 
-void TransportManager::migrateToWallet()
+void TransportManagerPrivate::migrateToWallet()
 {
   // check if we tried this already
   static bool firstRun = true;
@@ -531,13 +713,13 @@ void TransportManager::migrateToWallet()
   firstRun = false;
 
   // check if we are the main instance
-  if ( !d->isMainInstance ) {
+  if ( !isMainInstance ) {
     return;
   }
 
   // check if migration is needed
   QStringList names;
-  foreach ( Transport *t, d->transports ) {
+  foreach ( Transport *t, transports ) {
     if ( t->needsWalletMigration() ) {
       names << t->name();
     }
@@ -563,16 +745,16 @@ void TransportManager::migrateToWallet()
   }
 
   // perform migration
-  foreach ( Transport *t, d->transports ) {
+  foreach ( Transport *t, transports ) {
     if ( t->needsWalletMigration() ) {
       t->migrateToWallet();
     }
   }
 }
 
-void TransportManager::dbusServiceOwnerChanged( const QString &service,
-                                                const QString &oldOwner,
-                                                const QString &newOwner )
+void TransportManagerPrivate::dbusServiceOwnerChanged( const QString &service,
+                                                         const QString &oldOwner,
+                                                         const QString &newOwner )
 {
   Q_UNUSED( oldOwner );
   if ( service == DBUS_SERVICE_NAME && newOwner.isEmpty() ) {
@@ -580,9 +762,35 @@ void TransportManager::dbusServiceOwnerChanged( const QString &service,
   }
 }
 
-void TransportManager::jobResult( KJob *job )
+void TransportManagerPrivate::agentTypeAdded( const Akonadi::AgentType &atype )
 {
-  d->walletQueue.removeAll( static_cast<TransportJob*>( job ) );
+  using namespace Akonadi;
+  if( atype.capabilities().contains( QLatin1String( "MailTransport" ) ) ) {
+    TransportType type;
+    type.d->mType = Transport::EnumType::Akonadi;
+    type.d->mAgentType = atype;
+    type.d->mName = atype.name();
+    type.d->mDescription = atype.description();
+    types << type;
+    kDebug() << "Added new Akonadi type" << atype.name();
+  }
+}
+
+void TransportManagerPrivate::agentTypeRemoved( const Akonadi::AgentType &atype )
+{
+  using namespace Akonadi;
+  foreach ( const TransportType &type, types ) {
+    if( type.type() == Transport::EnumType::Akonadi &&
+        type.agentType() == atype ) {
+      types.removeAll( type );
+      kDebug() << "Removed Akonadi type" << atype.name();
+    }
+  }
+}
+
+void TransportManagerPrivate::jobResult( KJob *job )
+{
+  walletQueue.removeAll( static_cast<TransportJob*>( job ) );
 }
 
 #include "transportmanager.moc"
